pub fn verify(
key: &[u8],
token: &str,
now: u64,
) -> Result<ForgeAgent, TokenError>Expand description
Verify a token at now, returning the reconstructed caller identity.
pub fn verify(
key: &[u8],
token: &str,
now: u64,
) -> Result<ForgeAgent, TokenError>Verify a token at now, returning the reconstructed caller identity.